@@ -764,7 +764,10 @@ gtk_grid_view_size_allocate (GtkWidget *widget,
 
   /* step 0: exit early if list is empty */
   if (gtk_list_item_manager_get_root (self->item_manager) == NULL)
-    return;
+    {
+      gtk_list_base_update_adjustments (GTK_LIST_BASE (self), 0, 0, 0, 0, &x, &y);
+      return;
+    }
 
   /* step 1: determine width of the list */
   gtk_grid_view_measure_column_size (self, &col_min, &col_nat);
@@ -1060,9 +1063,7 @@ gtk_grid_view_class_init (GtkGridViewClass *klass)
    * Factory for populating list items.
    */
   properties[PROP_FACTORY] =
-    g_param_spec_object ("factory",
-                         P_("Factory"),
-                         P_("Factory for populating list items"),
+    g_param_spec_object ("factory", NULL, NULL,
                          GTK_TYPE_LIST_ITEM_FACTORY,
                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -1076,9 +1077,7 @@ gtk_grid_view_class_init (GtkGridViewClass *klass)
    * that value is used instead.
    */
   properties[PROP_MAX_COLUMNS] =
-    g_param_spec_uint ("max-columns",
-                       P_("Max columns"),
-                       P_("Maximum number of columns per row"),
+    g_param_spec_uint ("max-columns", NULL, NULL,
                        1, G_MAXUINT, DEFAULT_MAX_COLUMNS,
                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -1088,9 +1087,7 @@ gtk_grid_view_class_init (GtkGridViewClass *klass)
    * Minimum number of columns per row.
    */
   properties[PROP_MIN_COLUMNS] =
-    g_param_spec_uint ("min-columns",
-                       P_("Min columns"),
-                       P_("Minimum number of columns per row"),
+    g_param_spec_uint ("min-columns", NULL, NULL,
                        1, G_MAXUINT, 1,
                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -1100,9 +1097,7 @@ gtk_grid_view_class_init (GtkGridViewClass *klass)
    * Model for the items displayed.
    */
   properties[PROP_MODEL] =
-    g_param_spec_object ("model",
-                         P_("Model"),
-                         P_("Model for the items displayed"),
+    g_param_spec_object ("model", NULL, NULL,
                          GTK_TYPE_SELECTION_MODEL,
                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
@@ -1112,9 +1107,7 @@ gtk_grid_view_class_init (GtkGridViewClass *klass)
    * Activate rows on single click and select them on hover.
    */
   properties[PROP_SINGLE_CLICK_ACTIVATE] =
-    g_param_spec_boolean ("single-click-activate",
-                          P_("Single click activate"),
-                          P_("Activate rows on single click"),
+    g_param_spec_boolean ("single-click-activate", NULL, NULL,
                           FALSE,
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -1124,9 +1117,7 @@ gtk_grid_view_class_init (GtkGridViewClass *klass)
    * Allow rubberband selection.
    */
   properties[PROP_ENABLE_RUBBERBAND] =
-    g_param_spec_boolean ("enable-rubberband",
-                          P_("Enable rubberband selection"),
-                          P_("Allow selecting items by dragging with the mouse"),
+    g_param_spec_boolean ("enable-rubberband", NULL, NULL,
                           FALSE,
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
